@@ -3,7 +3,7 @@
 import logging
 import paho.mqtt.client as mqttc
 import ssl,json
-
+from datetime import datetime
 
 class MQTTHandlerLogging(logging.Handler):
     def __init__(
@@ -60,15 +60,16 @@ class MQTTHandlerLogging(logging.Handler):
 
     def emit(self, record):
         payload = {
-            'datetime':record.asctime,
-            'filename':record.filename,
-            'module':record.module,
-            'func_name':record.funcName,
-            'level_name':record.levelname,
-            'line_number':record.lineno,
-            'message':record.msg,
-            'path_name':record.pathname
+            'datetime': str(datetime.now()),
+            'filename': record.filename,
+            'module': record.module,
+            'func_name': record.funcName,
+            'level_name': record.levelname,
+            'line_number': record.lineno,
+            'message': record.msg,
+            'path_name': record.pathname
         }
+
         if not self._started:
             self._mqttc.loop_start()
             self._started = True
